"""
config_models Django application initialization.
"""

from django.apps import AppConfig


class ConfigModelsConfig(AppConfig):
    """
    Configuration for the config_models Django application.
    """

    name = 'config_models'
